

``zaya`` is a toolbox for the https://zaya.io community.


Install
-------

    pip3 install zaya


Usage
-------------

    import zaya


Connect
-------------

    zaya.connect('YourToken')

> account details

    zaya.account()

get Information from zaya
-------

    zaya.__version__
    zaya.__author__
    zaya.__website__
    zaya.__documentation__